# `automate_teaching`

`automate_teaching` is a Python module with utilities to assist educators, particularly in higher education, with tasks such as managing homework, creating multiple choice exams, sending emails, interacting with Google Calendar, and working with LaTeX files. The utilities for interacting with Gmail and Google Calendar may be useful in contexts outside of education

## Features
- Send and manage Gmail messages.
- Add, find, and delete Google Calendar events.
- Manage and format homework answers for Gradescope.
- Tools for creating multiple choice exams.
- Compile LaTeX files and create handouts for Beamer slides
- Convert Jupyter Notebooks to Python scripts or HTML files.

## Examples
 - [Sending and working with Gmail](docs/gmail.md)


## Documentation
- [Gmail Class](docs/gmail.md)
- [Google Calendar Class](docs/google_calendar.md)
- [Homework Class](docs/homework.md)
- [LaTeX Module](docs/latex.md)
- [Exam Module](docs/exam.md)
- [Standalone Functions](docs/functions.md)

## Installation
	pip install automate_teaching

## Documentation
Documentation for fredpy: https://www.briancjenkins.com/automate_teaching/docs/build/html/

_Updated: April 7, 2025_


<!-- ## Quickstart -->
